.. meta::
    :description lang=en:
        Track search engine results pages rankings and get meta data on Google
        and YouTube. Python functions to retrieve multiple SERPs on a large
        scale.

.. automodule:: advertools.serp
   :members:
   :undoc-members:
   :show-inheritance:
